==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/fr.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Agenda",
    "Todos" : "Tâches",
    "Personal" : "Personnel",
    "{actor} created calendar {calendar}" : "{actor} a créé l'agenda {calendar}",
    "You created calendar {calendar}" : "Vous avez créé l'agenda {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} a supprimé l'agenda {calendar}",
    "You deleted calendar {calendar}" : "Vous avez supprimé l'agenda {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} a mis à jour l'agenda {calendar}",
    "You updated calendar {calendar}" : "Vous avez mis à jour l'agenda {calendar}",
    "You shared calendar {calendar} as public link" : "Vous avez partagé l'agenda {calendar} avec un lien public ",
    "You removed public link for calendar {calendar}" : "Vous avez supprimé le lien public pour l'agenda {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} a partagé l'agenda {calendar} avec vous",
    "You shared calendar {calendar} with {user}" : "Vous avez partagé l'agenda {calendar} avec {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} a partagé l'agenda {calendar} avec {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} a cessé de partager l'agenda {calendar} avec vous",
    "You unshared calendar {calendar} from {user}" : "Vous avez cessé de partager l'agenda {calendar} avec {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} a cessé de partager l'agenda {calendar} avec {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} a cessé de partager l'agenda {calendar} avec lui-même",
    "You shared calendar {calendar} with group {group}" : "Vous avez partagé l'agenda {calendar} avec le groupe {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} a partagé l'agenda {calendar} avec le groupe {group}",
    "You unshared calendar {calendar} from group {group}" : "Vous avez cessé de partager l'agenda {calendar} avec le groupe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} a cessé de partager l'agenda {calendar} avec le groupe {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} a créé l'évènement {event} dans l'agenda {calendar}",
    "You created event {event} in calendar {calendar}" : "Vous avez créé l'évènement {event} dans l'agenda {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} a supprimé l'évènement {event} de l'agenda {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Vous avez supprimé l'évènement {event} de l'agenda {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} a mis à jour l'évènement {event} dans l'agenda {calendar}",
    "You updated event {event} in calendar {calendar}" : "Vous avez mis à jour l'évènement {event} dans l'agenda {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} a créé la tâche {todo} dans la liste {calendar}",
    "You created todo {todo} in list {calendar}" : "Vous avez créé la tâche {todo} dans la liste {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} a supprimé la tâche {todo} de la liste {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Vous avez supprimé la tâche {todo} de la liste {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} a mis à jour la tâche {todo} dans la liste {calendar}",
    "You updated todo {todo} in list {calendar}" : "Vous avez mis à jour la tâche {todo} dans la liste {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} a terminé la tâche {todo} de la liste {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vous avez terminé la tâche {todo} de la liste {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} a réouvert la tâche {todo} dans la liste {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Vous avez réouvert la tâche {todo} dans la liste {calendar}",
    "A <strong>calendar</strong> was modified" : "Un <strong>agenda</strong> a été modifié",
    "A calendar <strong>event</strong> was modified" : "Un <strong>événement</strong> de l'agenda a été modifié",
    "A calendar <strong>todo</strong> was modified" : "Une <strong>liste de tâches</strong> de l'agenda a été modifiée",
    "Contact birthdays" : "Anniversaires des contacts",
    "Invitation canceled" : "Invitation annulée",
    "Hello %s," : "Bonjour %s,",
    "Invitation updated" : "Invitation mise à jour",
    "When:" : "Quand :",
    "Where:" : "Où :",
    "Description:" : "Description :",
    "Link:" : "Lien :",
    "Accept" : "Accepter",
    "Decline" : "Refuser",
    "More options …" : "Plus d'options …",
    "More options at %s" : "Plus d'options à %s",
    "Contacts" : "Contacts",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Point d'accès WebDAV",
    "Technical details" : "Détails techniques",
    "Remote Address: %s" : "Adresse distante : %s",
    "Request ID: %s" : "ID de la requête : %s",
    "There was an error updating your attendance status." : "Une erreur s'est produite lors de la mise à jour de votre statut de présence.",
    "Please contact the organizer directly." : "Merci de contacter l'organisateur directement.",
    "Are you accepting the invitation?" : "Acceptez-vous l'invitation ?",
    "Tentative" : "Provisoire",
    "Save" : "Sauvegarder",
    "Your attendance was updated successfully." : "Votre présence a été mise à jour avec succès.",
    "Calendar server" : "Serveur de calendrier",
    "Send invitations to attendees" : "Envoyer des invitations aux participants",
    "Please make sure to properly set up the email settings above." : "Merci de vérifier d'avoir correctement configuré les paramètres de courriel ci-dessus",
    "Automatically generate a birthday calendar" : "Générer automatiquement un agenda d'anniversaire",
    "Birthday calendars will be generated by a background job." : "Les agendas d'anniversaire seront générés par une tâche de fond.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Par conséquent, ils ne seront pas disponibles immédiatement après l'activation mais apparaîtront après un certain temps.",
    "%s via %s" : "%s via %s",
    "The meeting »%s« with %s was canceled." : "La réunion «%s» avec %s a été annulée.",
    "The meeting »%s« with %s was updated." : "La réunion «%s» avec %s a été mise à jour.",
    "%s invited you to »%s«" : "%s vous a invité à «%s»",
    "CalDAV server" : "Serveur CalDAV"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/fr.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Agenda",
    "Todos" : "Tâches",
    "Personal" : "Personnel",
    "{actor} created calendar {calendar}" : "{actor} a créé l'agenda {calendar}",
    "You created calendar {calendar}" : "Vous avez créé l'agenda {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} a supprimé l'agenda {calendar}",
    "You deleted calendar {calendar}" : "Vous avez supprimé l'agenda {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} a mis à jour l'agenda {calendar}",
    "You updated calendar {calendar}" : "Vous avez mis à jour l'agenda {calendar}",
    "You shared calendar {calendar} as public link" : "Vous avez partagé l'agenda {calendar} avec un lien public ",
    "You removed public link for calendar {calendar}" : "Vous avez supprimé le lien public pour l'agenda {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} a partagé l'agenda {calendar} avec vous",
    "You shared calendar {calendar} with {user}" : "Vous avez partagé l'agenda {calendar} avec {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} a partagé l'agenda {calendar} avec {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} a cessé de partager l'agenda {calendar} avec vous",
    "You unshared calendar {calendar} from {user}" : "Vous avez cessé de partager l'agenda {calendar} avec {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} a cessé de partager l'agenda {calendar} avec {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} a cessé de partager l'agenda {calendar} avec lui-même",
    "You shared calendar {calendar} with group {group}" : "Vous avez partagé l'agenda {calendar} avec le groupe {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} a partagé l'agenda {calendar} avec le groupe {group}",
    "You unshared calendar {calendar} from group {group}" : "Vous avez cessé de partager l'agenda {calendar} avec le groupe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} a cessé de partager l'agenda {calendar} avec le groupe {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} a créé l'évènement {event} dans l'agenda {calendar}",
    "You created event {event} in calendar {calendar}" : "Vous avez créé l'évènement {event} dans l'agenda {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} a supprimé l'évènement {event} de l'agenda {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Vous avez supprimé l'évènement {event} de l'agenda {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} a mis à jour l'évènement {event} dans l'agenda {calendar}",
    "You updated event {event} in calendar {calendar}" : "Vous avez mis à jour l'évènement {event} dans l'agenda {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} a créé la tâche {todo} dans la liste {calendar}",
    "You created todo {todo} in list {calendar}" : "Vous avez créé la tâche {todo} dans la liste {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} a supprimé la tâche {todo} de la liste {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Vous avez supprimé la tâche {todo} de la liste {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} a mis à jour la tâche {todo} dans la liste {calendar}",
    "You updated todo {todo} in list {calendar}" : "Vous avez mis à jour la tâche {todo} dans la liste {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} a terminé la tâche {todo} de la liste {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vous avez terminé la tâche {todo} de la liste {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} a réouvert la tâche {todo} dans la liste {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Vous avez réouvert la tâche {todo} dans la liste {calendar}",
    "A <strong>calendar</strong> was modified" : "Un <strong>agenda</strong> a été modifié",
    "A calendar <strong>event</strong> was modified" : "Un <strong>événement</strong> de l'agenda a été modifié",
    "A calendar <strong>todo</strong> was modified" : "Une <strong>liste de tâches</strong> de l'agenda a été modifiée",
    "Contact birthdays" : "Anniversaires des contacts",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Invitation canceled" : "Invitation annulée",
    "Hello %s," : "Bonjour %s,",
    "The meeting »%1$s« with %2$s was canceled." : "La réunion «%1$s» avec %2$s a été annulée.",
    "Invitation updated" : "Invitation mise à jour",
    "The meeting »%1$s« with %2$s was updated." : "La réunion «%1$s» avec %2$s a été mise à jour.",
    "%1$s invited you to »%2$s«" : "%1$s vous a invité à «%2$s»",
    "When:" : "Quand :",
    "Where:" : "Où :",
    "Description:" : "Description :",
    "Link:" : "Lien :",
    "Accept" : "Accepter",
    "Decline" : "Refuser",
    "More options …" : "Plus d'options …",
    "More options at %s" : "Plus d'options à %s",
    "Contacts" : "Contacts",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Point d'accès WebDAV",
    "Technical details" : "Détails techniques",
    "Remote Address: %s" : "Adresse distante : %s",
    "Request ID: %s" : "ID de la requête : %s",
    "There was an error updating your attendance status." : "Une erreur s'est produite lors de la mise à jour de votre statut de présence.",
    "Please contact the organizer directly." : "Merci de contacter l'organisateur directement.",
    "Are you accepting the invitation?" : "Acceptez-vous l'invitation ?",
    "Tentative" : "Provisoire",
    "Save" : "Sauvegarder",
    "Your attendance was updated successfully." : "Votre présence a été mise à jour avec succès.",
    "Calendar server" : "Serveur de calendrier",
    "Send invitations to attendees" : "Envoyer des invitations aux participants",
    "Please make sure to properly set up the email settings above." : "Merci de vérifier d'avoir correctement configuré les paramètres de courriel ci-dessus",
    "Automatically generate a birthday calendar" : "Générer automatiquement un agenda d'anniversaire",
    "Birthday calendars will be generated by a background job." : "Les agendas d'anniversaire seront générés par une tâche de fond.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Par conséquent, ils ne seront pas disponibles immédiatement après l'activation mais apparaîtront après un certain temps.",
    "%s via %s" : "%s via %s",
    "The meeting »%s« with %s was canceled." : "La réunion «%s» avec %s a été annulée.",
    "The meeting »%s« with %s was updated." : "La réunion «%s» avec %s a été mise à jour.",
    "%s invited you to »%s«" : "%s vous a invité à «%s»",
    "CalDAV server" : "Serveur CalDAV"
},
"nplurals=2; plural=(n > 1);");
